#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.adom.de/adom/roguelike.php3
# source           : http://www.adom.de/adom/download/linux/adom-111-elf.tar.gz
#
# This game is postcardware

# Package name
NAME="adom"
# Package version
VERSION="111"
# Source code URL
SOURCE="http://www.adom.de/adom/download/linux/adom-111-elf.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="adomfaq.txt manual.doc readme.1st"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: adom - a roguelike game
$NAME:
$NAME: Ancient Domains of Mystery (ADOM for short) is a roguelike game
$NAME: which means that it is a single-user game featuring the exploration
$NAME: of a dungeon complex (and in the case of ADOM and a few other games
$NAME: of this genre: the exploration of a large wilderness area with
$NAME: villages and many special locations). You control a fictional
$NAME: character described by race, class, attributes, skills, and
$NAME: equipment. Your character is trying to achieve a specific goal 
$NAME: and succeed in a difficult quest.
$NAME: This game is postcardware.
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME
if [ -f $NAME-$VERSION-elf.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if an icon is present. If it's not, download it
if [ -f $NAME.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.png
fi

# Unpack source
tar xvzf $NAME-$VERSION-elf.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Ancient Domains of Mystery
Exec=xterm -geometry 100x30 -title "Ancient Domains of Mystery" -e adom
Terminal=false
Type=Application
Categories=Game;RolePlaying;
Icon=adom
EOF

# just copy stuff
cd $NAME
mkdir $PKG/usr/bin
cp -a adom $PKG/usr/bin

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy icon to the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp -a $CWD/$NAME.png $PKG/usr/share/icons/hicolor/48x48/apps

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME
rm -rf $PKG
